@@ -22,6 +22,7 @@
 #include "lib/synchtimer.h"
 
 #include <KHolidays/HolidayRegion>
+#include <kholidays_version.h>
 #include <KLocalizedString>
 
 #include <QMenu>
@@ -194,7 +195,12 @@ void DayMatrix::updateView()
 
     // Find which holidays occur for the dates in the matrix.
     const KHolidays::HolidayRegion& region = Preferences::holidays();
+#if KHOLIDAYS_VERSION < QT_VERSION_CHECK(5, 95, 0)
     const KHolidays::Holiday::List list = region.holidays(mStartDate, mStartDate.addDays(NUMDAYS-1));
+#else
+    const KHolidays::Holiday::List list = region.rawHolidaysWithAstroSeasons(mStartDate, mStartDate.addDays(NUMDAYS-1));
+#endif
+
     QHash<QDate, QStringList> holidaysByDate;
     for (const KHolidays::Holiday& holiday : list)
         if (!holiday.name().isEmpty())
@@ -481,7 +487,11 @@ void DayMatrix::paintEvent(QPaintEvent*)
     QSet<QDate> nonWorkHolidays;
     {
         const KHolidays::HolidayRegion& region = Preferences::holidays();
+#if KHOLIDAYS_VERSION < QT_VERSION_CHECK(5, 95, 0)
         const KHolidays::Holiday::List list = region.holidays(mStartDate, mStartDate.addDays(NUMDAYS-1));
+#else
+        const KHolidays::Holiday::List list = region.rawHolidaysWithAstroSeasons(mStartDate, mStartDate.addDays(NUMDAYS-1));
+#endif
         for (const KHolidays::Holiday& holiday : list)
             if (holiday.dayType() == KHolidays::Holiday::NonWorkday)
                 nonWorkHolidays += holiday.observedStartDate();
