@@ -23,7 +23,6 @@
 #include "sounddlg.h"
 #include "specialactions.h"
 #include "templatepickdlg.h"
-#include "lib/autoqpointer.h"
 #include "lib/buttongroup.h"
 #include "lib/checkbox.h"
 #include "lib/colourbutton.h"
@@ -35,9 +34,9 @@
 #include "lib/shellprocess.h"
 #include "lib/timespinbox.h"
 #include "kalarmcalendar/identities.h"
+#include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
-#include <Akonadi/EmailAddressSelectionDialog>
 #include <KCalUtils/ICalDrag>
 #include <KCalendarCore/Person>
 
@@ -53,6 +52,7 @@
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QDragEnterEvent>
+#include <QMimeData>
 #include <QStandardItemModel>
 
 using namespace KAlarmCal;
@@ -286,18 +286,15 @@ CheckBox* EditDisplayAlarmDlg::createConfirmAckCheckbox(QWidget* parent)
 void EditDisplayAlarmDlg::type_initValues(const KAEvent& event)
 {
     mTryButton->setToolTip(i18nc("@info:tooltip", "Display the alarm now"));
-    mAkonadiItemId = -1;
+    mEmailId = -1;
     lateCancel()->showAutoClose(true);
     if (event.isValid())
     {
-        if (mAlarmType == KAEvent::MESSAGE  &&  event.akonadiItemId()
+        if (mAlarmType == KAEvent::MESSAGE  &&  event.emailId()
         &&  AlarmText::checkIfEmail(event.cleanText()))
-            mAkonadiItemId = event.akonadiItemId();
+            mEmailId = event.emailId();
         lateCancel()->setAutoClose(event.autoClose());
-        if (event.useDefaultFont())
-            mFontColourButton->setDefaultFont();
-        else
-            mFontColourButton->setFont(event.font());
+        mFontColourButton->setFont(event.font(), event.useDefaultFont());
         mFontColourButton->setBgColour(event.bgColour());
         mFontColourButton->setFgColour(event.fgColour());
         setColours(event.fgColour(), event.bgColour());
@@ -343,7 +340,7 @@ void EditDisplayAlarmDlg::type_initValues(const KAEvent& event)
         }
         lateCancel()->setAutoClose(Preferences::defaultAutoClose());
         mTypeCombo->setCurrentIndex(0);
-        mFontColourButton->setDefaultFont();
+        mFontColourButton->setFont(Preferences::messageFont(), true);
         mFontColourButton->setBgColour(Preferences::defaultBgColour());
         mFontColourButton->setFgColour(Preferences::defaultFgColour());
         setColours(Preferences::defaultFgColour(), Preferences::defaultBgColour());
@@ -432,7 +429,7 @@ void EditDisplayAlarmDlg::setAction(KAEvent::SubAction action, const AlarmText&
         case KAEvent::MESSAGE:
             mTypeCombo->setCurrentIndex(tTEXT);
             mTextMessageEdit->setPlainText(text);
-            mAkonadiItemId = alarmText.isEmail() ? alarmText.akonadiItemId() : -1;
+            mEmailId = alarmText.isEmail() ? alarmText.emailId() : -1;
             break;
         case KAEvent::FILE:
             mTypeCombo->setCurrentIndex(tFILE);
@@ -615,7 +612,7 @@ void EditDisplayAlarmDlg::type_setEvent(KAEvent& event, const KADateTime& dt, co
     if (type == KAEvent::MESSAGE)
     {
         if (AlarmText::checkIfEmail(text))
-            event.setAkonadiItemId(mAkonadiItemId);
+            event.setEmailId(mEmailId);
     }
     float fadeVolume;
     int   fadeSecs;
@@ -1194,14 +1191,20 @@ void EditEmailAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     mEmailToEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the addresses of the email recipients. Separate multiple addresses by "
                                     "commas or semicolons."));
     connect(mEmailToEdit, &LineEdit::textChanged, this, &EditEmailAlarmDlg::contentsChanged);
-    grid->addWidget(mEmailToEdit, 1, 1);
 
-    mEmailAddressButton = new QPushButton(parent);
-    mEmailAddressButton->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
-    connect(mEmailAddressButton, &QPushButton::clicked, this, &EditEmailAlarmDlg::openAddressBook);
-    mEmailAddressButton->setToolTip(i18nc("@info:tooltip", "Open address book"));
-    mEmailAddressButton->setWhatsThis(i18nc("@info:whatsthis", "Select email addresses from your address book."));
-    grid->addWidget(mEmailAddressButton, 1, 2);
+    if (Preferences::useAkonadi())
+    {
+        grid->addWidget(mEmailToEdit, 1, 1);
+
+        mEmailAddressButton = new QPushButton(parent);
+        mEmailAddressButton->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
+        connect(mEmailAddressButton, &QPushButton::clicked, this, &EditEmailAlarmDlg::openAddressBook);
+        mEmailAddressButton->setToolTip(i18nc("@info:tooltip", "Open address book"));
+        mEmailAddressButton->setWhatsThis(i18nc("@info:whatsthis", "Select email addresses from your address book."));
+        grid->addWidget(mEmailAddressButton, 1, 2);
+    }
+    else
+        grid->addWidget(mEmailToEdit, 1, 1, 1, 2);
 
     // Email subject
     label = new QLabel(i18nc("@label:textbox Email subject", "Subject:"), parent);
@@ -1341,13 +1344,15 @@ void EditEmailAlarmDlg::setReadOnly(bool readOnly)
         mEmailFromList->setReadOnly(readOnly);
     if (readOnly)
     {
-        mEmailAddressButton->hide();
+        if (mEmailAddressButton)
+            mEmailAddressButton->hide();
         mEmailAddAttachButton->hide();
         mEmailRemoveButton->hide();
     }
     else
     {
-        mEmailAddressButton->show();
+        if (mEmailAddressButton)
+            mEmailAddressButton->show();
         mEmailAddAttachButton->show();
         mEmailRemoveButton->show();
     }
@@ -1496,22 +1501,18 @@ void EditEmailAlarmDlg::slotTrySuccess()
 */
 void EditEmailAlarmDlg::openAddressBook()
 {
-    // Use AutoQPointer to guard against crash on application exit while
-    // the dialogue is still open. It prevents double deletion (both on
-    // deletion of MainWindow, and on return from this function).
-    AutoQPointer<Akonadi::EmailAddressSelectionDialog> dlg = new Akonadi::EmailAddressSelectionDialog(this);
-    if (dlg->exec() != QDialog::Accepted)
-        return;
-
-    Akonadi::EmailAddressSelection::List selections = dlg->selectedAddresses();
-    if (selections.isEmpty())
-        return;
-    const Person person(selections.first().name(), selections.first().email());
-    QString addrs = mEmailToEdit->text().trimmed();
-    if (!addrs.isEmpty())
-        addrs += QLatin1String(", ");
-    addrs += person.fullName();
-    mEmailToEdit->setText(addrs);
+    AkonadiPlugin* akonadiPlugin = Preferences::akonadiPlugin();
+    if (akonadiPlugin)
+    {
+        Person person;
+        if (!akonadiPlugin->getAddressBookSelection(person, this))
+            return;
+        QString addrs = mEmailToEdit->text().trimmed();
+        if (!addrs.isEmpty())
+            addrs += QLatin1String(", ");
+        addrs += person.fullName();
+        mEmailToEdit->setText(addrs);
+    }
 }
 
 /******************************************************************************
@@ -2003,8 +2004,7 @@ void TextEdit::dropEvent(QDropEvent* e)
         else
         {
             QUrl url;
-            Akonadi::Item item;
-            if (DragDrop::dropAkonadiEmail(data, url, item, alarmText))
+            if (KAlarm::dropAkonadiEmail(data, url, alarmText))
             {
                 // It's an email held in Akonadi
                 qCDebug(KALARM_LOG) << "TextEdit::dropEvent: Akonadi email";
