@@ -1,7 +1,7 @@
 /*
  *  kamail.cpp  -  email functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -14,17 +14,14 @@
 #include "mainwindow.h"
 #include "preferences.h"
 #include "lib/messagebox.h"
+#include "kalarmcalendar/identities.h"
+#include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
 #include "kmailinterface.h"
 
-#include <KAlarmCal/Identities>
-
 #include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
-#include <MailTransport/TransportManager>
-#include <MailTransport/Transport>
-#include <MailTransportAkonadi/MessageQueueJob>
 #include <KMime/HeaderParsing>
 #include <KMime/Headers>
 #include <KMime/Message>
@@ -55,21 +52,22 @@
 #define pclose _pclose
 #endif
 
-static const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
-//static const QLatin1String KMAIL_DBUS_PATH("/KMail");
+using namespace MailSend;
 
 namespace HeaderParsing
 {
-bool parseAddress( const char* & scursor, const char * const send,
-                   KMime::Types::Address & result, bool isCRLF=false );
+bool parseAddress(const char* & scursor, const char* const send,
+                  KMime::Types::Address& result, bool isCRLF = false);
 }
 
-static void initHeaders(KMime::Message&, KAMail::JobData&);
-static KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalidItem);
-static QString     extractEmailAndNormalize(const QString& emailAddress);
-static QStringList extractEmailsAndNormalize(const QString& emailAddresses);
-static QByteArray autoDetectCharset(const QString& text);
-static const QTextCodec* codecForName(const QByteArray& str);
+namespace
+{
+void                        initHeaders(KMime::Message&, JobData&);
+KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalidItem);
+QString                     extractEmailAndNormalize(const QString& emailAddress);
+QByteArray                  autoDetectCharset(const QString& text);
+const QTextCodec*           codecForName(const QByteArray& str);
+}
 
 QString KAMail::i18n_NeedFromEmailAddress()
 { return i18nc("@info", "A 'From' email address must be configured in order to execute email alarms."); }
@@ -77,9 +75,8 @@ QString KAMail::i18n_NeedFromEmailAddress()
 QString KAMail::i18n_sent_mail()
 { return i18nc("@info KMail folder name: this should be translated the same as in kmail", "sent-mail"); }
 
-KAMail*                                 KAMail::mInstance = nullptr;   // used only to enable signals/slots to work
-QQueue<MailTransport::MessageQueueJob*> KAMail::mJobs;
-QQueue<KAMail::JobData>                 KAMail::mJobData;
+KAMail*        KAMail::mInstance = nullptr;   // used only to enable signals/slots to work
+AkonadiPlugin* KAMail::mAkonadiPlugin = nullptr;
 
 KAMail* KAMail::instance()
 {
@@ -127,7 +124,7 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
                 break;
             case Preferences::MAIL_FROM_SYS_SETTINGS:
                 errmsgs = errors(xi18nc("@info", "<para>No 'From' email address is configured.</para>"
-                                                "<para>Please set a default address in <application>KMail</application> or KDE System Settings or in the <application>KAlarm</application> Configuration dialog.</para>"));
+                                                "<para>Please set a default address in <application>KMail</application> or in the <application>KAlarm</application> Configuration dialog.</para>"));
                 break;
             case Preferences::MAIL_FROM_ADDR:
             default:
@@ -143,8 +140,6 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
 
     KMime::Message::Ptr message = KMime::Message::Ptr(new KMime::Message);
 
-    MailTransport::TransportManager* manager = MailTransport::TransportManager::self();
-    MailTransport::Transport* transport = nullptr;
     if (Preferences::emailClient() == Preferences::sendmail)
     {
         qCDebug(KALARM_LOG) << "KAMail::send: Sending via sendmail";
@@ -202,34 +197,13 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
         fwrite(encoded.constData(), encoded.length(), 1, fd);
         pclose(fd);
 
-#ifdef KMAIL_SUPPORTED
-        if (Preferences::emailCopyToKMail())
-        {
-            // Create a copy of the sent email in KMail's 'sent-mail' folder,
-            // or if there was a send error, in KMail's 'outbox' folder.
-            err = addToKMailFolder(jobdata, "sent-mail", true);
-            if (!err.isNull())
-                errmsgs += errors(err, COPY_ERROR);    // not a fatal error - continue
-        }
-#endif
-
         if (jobdata.allowNotify)
             notifyQueued(jobdata.event);
         return 1;
     }
-    else
+    else if (Preferences::useAkonadi())
     {
         qCDebug(KALARM_LOG) << "KAMail::send: Sending via KDE";
-        const int transportId = identity.transport().isEmpty() ? -1 : identity.transport().toInt();
-        transport = manager->transportById(transportId, true);
-        if (!transport)
-        {
-            qCCritical(KALARM_LOG) << "KAMail::send: No mail transport found for identity" << identity.identityName() << "uoid" << identity.uoid();
-            errmsgs = errors(xi18nc("@info", "No mail transport configured for email identity <resource>%1</resource>", identity.identityName()));
-            return -1;
-        }
-        qCDebug(KALARM_LOG) << "KAMail::send: Using transport" << transport->name() << ", id=" << transport->id();
-
         initHeaders(*message, jobdata);
         err = appendBodyAttachments(*message, jobdata);
         if (!err.isNull())
@@ -239,110 +213,32 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
             return -1;
         }
 
-        auto mailjob = new MailTransport::MessageQueueJob(qApp);
-        mailjob->setMessage(message);
-        mailjob->transportAttribute().setTransportId(transport->id());
-        // MessageQueueJob email addresses must be pure, i.e. without display name. Note
-        // that display names are included in the actual headers set up by initHeaders().
-        mailjob->addressAttribute().setFrom(extractEmailAndNormalize(jobdata.from));
-        mailjob->addressAttribute().setTo(extractEmailsAndNormalize(jobdata.event.emailAddresses(QStringLiteral(","))));
-        if (!jobdata.bcc.isEmpty())
-            mailjob->addressAttribute().setBcc(extractEmailsAndNormalize(jobdata.bcc));
-        MailTransport::SentBehaviourAttribute::SentBehaviour sentAction =
-                             (Preferences::emailClient() == Preferences::kmail || Preferences::emailCopyToKMail())
-                             ? MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection : MailTransport::SentBehaviourAttribute::Delete;
-        mailjob->sentBehaviourAttribute().setSentBehaviour(sentAction);
-        mJobs.enqueue(mailjob);
-        mJobData.enqueue(jobdata);
-        if (mJobs.count() == 1)
+        if (!mAkonadiPlugin)
         {
-            // There are no jobs already active or queued, so send now
-            connect(mailjob, &KJob::result, instance(), &KAMail::slotEmailSent);
-            mailjob->start();
+            mAkonadiPlugin = Preferences::akonadiPlugin();
+            connect(mAkonadiPlugin, &AkonadiPlugin::emailSent, instance(), &KAMail::akonadiEmailSent);
+            connect(mAkonadiPlugin, &AkonadiPlugin::emailQueued, instance(), [](const KAEvent& e) { notifyQueued(e); });
+        }
+        const bool keepEmail = (Preferences::emailClient() == Preferences::kmail || Preferences::emailCopyToKMail());
+        err = mAkonadiPlugin->sendMail(message, identity, extractEmailAndNormalize(jobdata.from), keepEmail, jobdata);
+        if (!err.isEmpty())
+        {
+            errmsgs = errors(err);
+            return -1;
         }
     }
     return 0;
 }
 
 /******************************************************************************
-* Called when sending an email is complete.
+* Called when sending an email via Akonadi is complete.
 */
-void KAMail::slotEmailSent(KJob* job)
+void KAMail::akonadiEmailSent(const JobData& jobdata, const QStringList& errmsgs, bool sendError)
 {
-    bool copyerr = false;
-    QStringList errmsgs;
-    if (job->error())
-    {
-        qCCritical(KALARM_LOG) << "KAMail::slotEmailSent: Failed:" << job->errorString();
-        errmsgs = errors(job->errorString(), SEND_ERROR);
-    }
-    JobData jobdata;
-    if (mJobs.isEmpty()  ||  mJobData.isEmpty()  ||  job != std::as_const(mJobs).head())
-    {
-        // The queue has been corrupted, so we can't locate the job's data
-        qCCritical(KALARM_LOG) << "KAMail::slotEmailSent: Wrong job at head of queue: wiping queue";
-        mJobs.clear();
-        mJobData.clear();
-        if (!errmsgs.isEmpty())
-            theApp()->emailSent(jobdata, errmsgs);
-        errmsgs.clear();
-        errmsgs += i18nc("@info", "Emails may not have been sent");
-        errmsgs += i18nc("@info", "Program error");
-        theApp()->emailSent(jobdata, errmsgs);
-        return;
-    }
-    mJobs.dequeue();
-    jobdata = mJobData.dequeue();
-    if (jobdata.allowNotify)
-        notifyQueued(jobdata.event);
-    theApp()->emailSent(jobdata, errmsgs, copyerr);
-    if (!mJobs.isEmpty())
-    {
-        // Send the next queued email
-        auto job = mJobs.head();
-        connect(job, &KJob::result, instance(), &KAMail::slotEmailSent);
-        job->start();
-    }
-}
-
-/******************************************************************************
-* Create the headers part of the email.
-*/
-void initHeaders(KMime::Message& message, KAMail::JobData& data)
-{
-    auto date = new KMime::Headers::Date;
-    date->setDateTime(KADateTime::currentDateTime(Preferences::timeSpec()).qDateTime());
-    message.setHeader(date);
-
-    auto from = new KMime::Headers::From;
-    from->fromUnicodeString(data.from, autoDetectCharset(data.from));
-    message.setHeader(from);
-
-    auto to = new KMime::Headers::To;
-    const KCalendarCore::Person::List toList = data.event.emailAddressees();
-    for (const KCalendarCore::Person& who : toList)
-        to->addAddress(who.email().toLatin1(), who.name());
-    message.setHeader(to);
-
-    if (!data.bcc.isEmpty())
-    {
-        auto bcc = new KMime::Headers::Bcc;
-        bcc->fromUnicodeString(data.bcc, autoDetectCharset(data.bcc));
-        message.setHeader(bcc);
-    }
-
-    auto subject = new KMime::Headers::Subject;
-    const QString str = data.event.emailSubject();
-    subject->fromUnicodeString(str, autoDetectCharset(str));
-    message.setHeader(subject);
-
-    auto agent = new KMime::Headers::UserAgent;
-    agent->fromUnicodeString(KAboutData::applicationData().displayName() + QLatin1String("/" KALARM_VERSION), "us-ascii");
-    message.setHeader(agent);
-
-    auto id = new KMime::Headers::MessageID;
-    id->generate(data.from.mid(data.from.indexOf(QLatin1Char('@')) + 1).toLatin1());
-    message.setHeader(id);
+    QStringList messages = errmsgs;
+    if (!errmsgs.isEmpty()  &&  sendError)
+        messages = errors(errmsgs.at(0), SEND_ERROR);
+    theApp()->emailSent(jobdata, messages);
 }
 
 /******************************************************************************
@@ -458,7 +354,7 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
         }
         message.assemble();
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -489,7 +385,7 @@ void KAMail::notifyQueued(const KAEvent& event)
 }
 
 /******************************************************************************
-* Fetch the user's email address configured in KMail or KDE System Settings.
+* Fetch the user's email address configured in KMail.
 */
 QString KAMail::controlCentreAddress()
 {
@@ -514,7 +410,7 @@ QString KAMail::convertAddresses(const QString& items, KCalendarCore::Person::Li
         const KCalendarCore::Person person(mailbox.name(), mailbox.addrSpec().asString());
         list += person;
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -597,7 +493,7 @@ QString KAMail::convertAttachments(const QString& items, QStringList& list)
         }
         next = i + 1;
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -649,30 +545,53 @@ QStringList KAMail::errors(const QString& err, ErrType prefix)
     {
         case SEND_FAIL:   error1 = i18nc("@info", "Failed to send email");  break;
         case SEND_ERROR:  error1 = i18nc("@info", "Error sending email");  break;
-#ifdef KMAIL_SUPPORTED
-        case COPY_ERROR:  error1 = i18nc("@info", "Error copying sent email to <application>KMail</application> <resource>%1</resource> folder", i18n_sent_mail());  break;
-#endif
     }
     if (err.isEmpty())
         return QStringList(error1);
     return QStringList{QStringLiteral("%1:").arg(error1), err};
 }
 
-/******************************************************************************
-* Get the body of an email from KMail, given its serial number.
-*/
-QString KAMail::getMailBody(quint32 serialNumber)
+namespace
 {
-//TODO: Need to use Akonadi instead
-    const QList<QVariant> args{serialNumber, (int)0};       //clazy:exclude=inefficient-qlist
-    QDBusInterface iface(KMAIL_DBUS_SERVICE, QString(), QStringLiteral("KMailIface"));
-    const QDBusReply<QString> reply = iface.callWithArgumentList(QDBus::Block, QStringLiteral("getDecodedBodyPart"), args);
-    if (!reply.isValid())
+
+/******************************************************************************
+* Create the headers part of the email.
+*/
+void initHeaders(KMime::Message& message, JobData& data)
+{
+    auto date = new KMime::Headers::Date;
+    date->setDateTime(KADateTime::currentDateTime(Preferences::timeSpec()).qDateTime());
+    message.setHeader(date);
+
+    auto from = new KMime::Headers::From;
+    from->fromUnicodeString(data.from, autoDetectCharset(data.from));
+    message.setHeader(from);
+
+    auto to = new KMime::Headers::To;
+    const KCalendarCore::Person::List toList = data.event.emailAddressees();
+    for (const KCalendarCore::Person& who : toList)
+        to->addAddress(who.email().toLatin1(), who.name());
+    message.setHeader(to);
+
+    if (!data.bcc.isEmpty())
     {
-        qCCritical(KALARM_LOG) << "KAMail::getMailBody: D-Bus call failed:" << reply.error().message();
-        return QString();
+        auto bcc = new KMime::Headers::Bcc;
+        bcc->fromUnicodeString(data.bcc, autoDetectCharset(data.bcc));
+        message.setHeader(bcc);
     }
-    return reply.value();
+
+    auto subject = new KMime::Headers::Subject;
+    const QString str = data.event.emailSubject();
+    subject->fromUnicodeString(str, autoDetectCharset(str));
+    message.setHeader(subject);
+
+    auto agent = new KMime::Headers::UserAgent;
+    agent->fromUnicodeString(KAboutData::applicationData().displayName() + QLatin1String("/" KALARM_VERSION), "us-ascii");
+    message.setHeader(agent);
+
+    auto id = new KMime::Headers::MessageID;
+    id->generate(data.from.mid(data.from.indexOf(QLatin1Char('@')) + 1).toLatin1());
+    message.setHeader(id);
 }
 
 /******************************************************************************
@@ -683,18 +602,6 @@ QString extractEmailAndNormalize(const QString& emailAddress)
     return KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(emailAddress));
 }
 
-QStringList extractEmailsAndNormalize(const QString& emailAddresses)
-{
-    const QStringList splitEmails(KEmailAddress::splitAddressList(emailAddresses));
-    QStringList normalizedEmail;
-    normalizedEmail.reserve(splitEmails.count());
-    for (const QString& email : splitEmails)
-    {
-        normalizedEmail << KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(email));
-    }
-    return normalizedEmail;
-}
-
 //-----------------------------------------------------------------------------
 // Based on KMail KMMsgBase::autoDetectCharset().
 QByteArray autoDetectCharset(const QString& text)
@@ -722,7 +629,7 @@ QByteArray autoDetectCharset(const QString& text)
             }
         }
     }
-    return QByteArray();
+    return {};
 }
 
 //-----------------------------------------------------------------------------
@@ -797,7 +704,7 @@ KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalid
                     else if (ch != ' ')
                     {
                         invalidItem = text.mid(start);
-                        return KMime::Types::Mailbox::List();
+                        return {};
                     }
                     break;
                 case 10:   // looking for closing quote
@@ -833,7 +740,7 @@ KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalid
             if (mbox.address().isEmpty())
             {
                 invalidItem = text.mid(start, endAddr - start);
-                return KMime::Types::Mailbox::List();
+                return {};
             }
             if (endName)
             {
@@ -854,6 +761,8 @@ KMime::Types::Mailbox::List parseAddresses(const QString& text, QString& invalid
     return list;
 }
 
+} // namespace
+
 /*=============================================================================
 =  HeaderParsing :  modified and additional functions.
 =  The following functions are modified from, or additional to, those in
@@ -871,37 +780,40 @@ using namespace KMime::HeaderParsing;
 * New function.
 * Allow a local user name to be specified as an email address.
 */
-bool parseUserName( const char* & scursor, const char * const send,
-                    QString & result, bool isCRLF ) {
+bool parseUserName(const char* & scursor, const char* const send, QString& result, bool isCRLF)
+{
+    QByteArray atom;
 
-  QByteArray atom;
+    if (scursor != send)
+    {
+        // first, eat any whitespace
+        eatCFWS(scursor, send, isCRLF);
 
-  if ( scursor != send ) {
-    // first, eat any whitespace
-    eatCFWS( scursor, send, isCRLF );
+        char ch = *scursor++;
+        switch (ch)
+        {
+            case '.': // dot
+            case '@':
+            case '"': // quoted-string
+                return false;
 
-    char ch = *scursor++;
-    switch ( ch ) {
-    case '.': // dot
-    case '@':
-    case '"': // quoted-string
-      return false;
-
-    default: // atom
-      scursor--; // re-set scursor to point to ch again
-      if ( parseAtom( scursor, send, atom, false /* no 8bit */ ) ) {
-          //TODO FIXME on windows
+            default: // atom
+                scursor--; // re-set scursor to point to ch again
+                if (parseAtom(scursor, send, atom, false /* no 8bit */))
+                {
+                    //TODO FIXME on windows
 #ifndef WIN32
-        if (getpwnam(atom.constData())) {
-          result = QLatin1String(atom);
-          return true;
-        }
+                    if (getpwnam(atom.constData()))
+                    {
+                        result = QLatin1String(atom);
+                        return true;
+                    }
 #endif
-      }
-      return false; // parseAtom can only fail if the first char is non-atext.
+                }
+                return false; // parseAtom can only fail if the first char is non-atext.
+        }
     }
-  }
-  return false;
+    return false;
 }
 
 /******************************************************************************
@@ -909,52 +821,54 @@ bool parseUserName( const char* & scursor, const char * const send,
 * Allow a local user name to be specified as an email address, and reinstate
 * the original scursor on error return.
 */
-bool parseAddress( const char* & scursor, const char * const send,
-                   Address & result, bool isCRLF ) {
-  // address       := mailbox / group
+bool parseAddress(const char* & scursor, const char* const send, Address& result, bool isCRLF)
+{
+    // address       := mailbox / group
 
-  eatCFWS( scursor, send, isCRLF );
-  if ( scursor == send )
-    return false;
+    eatCFWS(scursor, send, isCRLF);
+    if (scursor == send)
+        return false;
 
-  // first try if it's a single mailbox:
-  Mailbox maybeMailbox;
-  const char * oldscursor = scursor;
-  if ( parseMailbox( scursor, send, maybeMailbox, isCRLF ) ) {
-    // yes, it is:
-    result.displayName.clear();
-    result.mailboxList.append( maybeMailbox );
+    // first try if it's a single mailbox:
+    Mailbox maybeMailbox;
+    const char * oldscursor = scursor;
+    if (parseMailbox(scursor, send, maybeMailbox, isCRLF))
+    {
+        // yes, it is:
+        result.displayName.clear();
+        result.mailboxList.append(maybeMailbox);
+        return true;
+    }
+    scursor = oldscursor;
+
+    // KAlarm: Allow a local user name to be specified
+    // no, it's not a single mailbox. Try if it's a local user name:
+    QString maybeUserName;
+    if (parseUserName(scursor, send, maybeUserName, isCRLF))
+    {
+        // yes, it is:
+        maybeMailbox.setName(QString());
+        AddrSpec addrSpec;
+        addrSpec.localPart = maybeUserName;
+        addrSpec.domain.clear();
+        maybeMailbox.setAddress(addrSpec);
+        result.displayName.clear();
+        result.mailboxList.append(maybeMailbox);
+        return true;
+    }
+    scursor = oldscursor;
+
+    Address maybeAddress;
+
+    // no, it's not a single mailbox. Try if it's a group:
+    if (!parseGroup(scursor, send, maybeAddress, isCRLF))
+    {
+        scursor = oldscursor;   // KAlarm: reinstate original scursor on error return
+        return false;
+    }
+
+    result = maybeAddress;
     return true;
-  }
-  scursor = oldscursor;
-
-  // KAlarm: Allow a local user name to be specified
-  // no, it's not a single mailbox. Try if it's a local user name:
-  QString maybeUserName;
-  if ( parseUserName( scursor, send, maybeUserName, isCRLF ) ) {
-    // yes, it is:
-    maybeMailbox.setName( QString() );
-    AddrSpec addrSpec;
-    addrSpec.localPart = maybeUserName;
-    addrSpec.domain.clear();
-    maybeMailbox.setAddress( addrSpec );
-    result.displayName.clear();
-    result.mailboxList.append( maybeMailbox );
-    return true;
-  }
-  scursor = oldscursor;
-
-  Address maybeAddress;
-
-  // no, it's not a single mailbox. Try if it's a group:
-  if ( !parseGroup( scursor, send, maybeAddress, isCRLF ) )
-  {
-    scursor = oldscursor;   // KAlarm: reinstate original scursor on error return
-    return false;
-  }
-
-  result = maybeAddress;
-  return true;
 }
 
 } // namespace HeaderParsing
