@@ -124,7 +124,7 @@ Resource Resources::getStandard(CalEvent::Type type, bool useOnlyResource)
         return defaultResource;
     }
 
-    return Resource();
+    return {};
 }
 
 /******************************************************************************
