@@ -13,11 +13,10 @@
 #include "singlefileresource.h"
 
 #include "resources.h"
+#include "kalarmcalendar/kacalendar.h"
+#include "kalarmcalendar/kaevent.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/KACalendar>
-#include <KAlarmCal/KAEvent>
-
 #include <KCalendarCore/ICalFormat>
 
 #include <KIO/Job>
@@ -243,7 +242,7 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
             {
                 f.remove();
                 qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Could not create writable file" << path;
-                errorMessage = xi18nc("@info", "Could not create calendar file <filename>%1</filename>.", path);
+                errorMessage = xi18nc("@info", "Could not create writable calendar file <filename>%1</filename>.", path);
                 mSaveUrl.clear();
                 setLoadFailure(false, Status::Broken);
                 return -1;
@@ -270,7 +269,6 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
             mDownloadJob->setProperty("QEventLoopLocker", QVariant::fromValue(ref));
             connect(mDownloadJob, &KJob::result,
                     this, &SingleFileResource::slotDownloadJobResult);
-//            connect(mDownloadJob, SIGNAL(percent(KJob*,ulong)), SLOT(handleProgress(KJob*,ulong)));
             setStatus(Status::Loading);
             return 0;     // loading initiated
         }
@@ -389,7 +387,6 @@ int SingleFileResource::doSave(bool writeThroughCache, bool force, QString& erro
         mUploadJob->setProperty("QEventLoopLocker", QVariant::fromValue(ref));
         connect(mUploadJob, &KJob::result,
                 this, &SingleFileResource::slotUploadJobResult);
-//        connect(mUploadJob, SIGNAL(percent(KJob*,ulong)), SLOT(handleProgress(KJob*,ulong)));
         setStatus(Status::Saving);
         return 0;
     }
@@ -427,9 +424,9 @@ void SingleFileResource::close()
         mDownloadJob->kill();
 
     save(nullptr, true);   // write through cache
-    // If a remote file upload job has been started, the use of
-    // QEventLoopLocker should ensure that it continues to completion even if
-    // the destructor for this instance is executed.
+    // If a remote file upload job has been started, the use of QEventLoopLocker
+    // in doSave() should ensure that it continues to completion even if the
+    // destructor for this instance is executed.
 
     if (mSettings  &&  mSettings->url().isLocalFile())
         KDirWatch::self()->removeFile(mSettings->url().toLocalFile());
@@ -679,7 +676,7 @@ QByteArray SingleFileResource::calculateHash(const QString& fileName) const
     {
         if (file.open(QIODevice::ReadOnly))
         {
-            const qint64 blockSize = 512 * 1024; // Read blocks of 512K
+            const qint64 blockSize = 512 * 1024;  // read blocks of 512K
             QCryptographicHash hash(QCryptographicHash::Md5);
 
             while (!file.atEnd())
@@ -690,7 +687,7 @@ QByteArray SingleFileResource::calculateHash(const QString& fileName) const
             return hash.result();
         }
     }
-    return QByteArray();
+    return {};
 }
 
 /******************************************************************************
